==> buildlog-consultant-0.0.2.tar.gz: buildlog-consultant-0.0.2/buildlog_consultant/__main__.py <==
#!/usr/bin/python
# Copyright (C) 2019-2021 Jelmer Vernooij <jelmer@jelmer.uk>
# encoding: utf-8
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from .sbuild import (
    worker_failure_from_sbuild_log,
    find_install_deps_failure_description,
    find_apt_get_update_failure,
    strip_useless_build_tail,
    parse_sbuild_log,
    SBUILD_FOCUS_SECTION,
    find_failed_stage,
    find_build_failure_description,
)


def main(argv=None):
    import argparse

    parser = argparse.ArgumentParser("buildlog-consultant")
    parser.add_argument("path", type=str)
    args = parser.parse_args()

    with open(args.path, "rb") as f:
        print(worker_failure_from_sbuild_log(f))

    # TODO(jelmer): Return more data from worker_failure_from_sbuild_log and
    # then use that here.
    section_offsets = {}
    section_lines = {}
    with open(args.path, "rb") as f:
        for title, offsets, lines in parse_sbuild_log(f):
            print("Section %s (lines %d-%d)" % (title, offsets[0], offsets[1]))
            if title is not None:
                title = title.lower()
            section_offsets[title] = offsets
            section_lines[title] = lines

    failed_stage = find_failed_stage(section_lines.get("summary", []))
    focus_section = SBUILD_FOCUS_SECTION.get(failed_stage)
    if failed_stage == "run-post-build-commands":
        # We used to run autopkgtest as the only post build
        # command.
        failed_stage = "autopkgtest"
    if failed_stage:
        print("Failed stage: %s (focus section: %s)" % (failed_stage, focus_section))
    if failed_stage in ("build", "autopkgtest"):
        lines = section_lines.get(focus_section, [])
        lines = strip_useless_build_tail(lines)
        match, error = find_build_failure_description(lines)
        if match:
            print("Failed line: %d:" % (section_offsets[focus_section][0] + match.lineno))
            print(match.line)
        if error:
            print("Error: %s" % error)
    if failed_stage == "apt-get-update":
        focus_section, offset, line, error = find_apt_get_update_failure(section_lines)
        if offset:
            print("Failed line: %d:" % (section_offsets[focus_section][0] + offset))
            print(line)
        if error:
            print("Error: %s" % error)
    if failed_stage == "install-deps":
        (focus_section, offset, line, error) = find_install_deps_failure_description(
            section_lines
        )
        if offset:
            print("Failed line: %d:" % (section_offsets[focus_section][0] + offset))
        if line:
            print(line)
        print(error)


if __name__ == "__main__":
    import sys

    sys.exit(main(sys.argv))

==> buildlog-consultant_0.0.3.orig.tar.gz: buildlog-consultant-0.0.3/buildlog_consultant/__main__.py <==
#!/usr/bin/python
# Copyright (C) 2019-2021 Jelmer Vernooij <jelmer@jelmer.uk>
# encoding: utf-8
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from .sbuild import (
    worker_failure_from_sbuild_log,
    find_install_deps_failure_description,
    find_apt_get_update_failure,
    strip_useless_build_tail,
    parse_sbuild_log,
    SBUILD_FOCUS_SECTION,
    find_failed_stage,
    find_build_failure_description,
)


def main(argv=None):
    import argparse

    parser = argparse.ArgumentParser("buildlog-consultant")
    parser.add_argument("path", type=str)
    args = parser.parse_args()

    with open(args.path, "rb") as f:
        print(worker_failure_from_sbuild_log(f))

    # TODO(jelmer): Return more data from worker_failure_from_sbuild_log and
    # then use that here.
    section_offsets = {}
    section_lines = {}
    with open(args.path, "rb") as f:
        for title, offsets, lines in parse_sbuild_log(f):
            print("Section %s (lines %d-%d)" % (title, offsets[0], offsets[1]))
            if title is not None:
                title = title.lower()
            section_offsets[title] = offsets
            section_lines[title] = lines

    failed_stage = find_failed_stage(section_lines.get("summary", []))
    focus_section = SBUILD_FOCUS_SECTION.get(failed_stage)
    if failed_stage == "run-post-build-commands":
        # We used to run autopkgtest as the only post build
        # command.
        failed_stage = "autopkgtest"
    if failed_stage:
        print("Failed stage: %s (focus section: %s)" % (failed_stage, focus_section))
    if failed_stage in ("build", "autopkgtest"):
        lines = section_lines.get(focus_section, [])
        lines = strip_useless_build_tail(lines)
        match, error = find_build_failure_description(lines)
        if match:
            print("Failed line: %d:" % (section_offsets[focus_section][0] + match.lineno))
            print(match.line)
        if error:
            print("Error: %s" % error)
    if failed_stage == "apt-get-update":
        focus_section, match, error = find_apt_get_update_failure(section_lines)
        if match:
            print("Failed line: %d:" % (section_offsets[focus_section][0] + match.lineno))
            print(match.line)
        if error:
            print("Error: %s" % error)
    if failed_stage == "install-deps":
        (focus_section, match, error) = find_install_deps_failure_description(
            section_lines
        )
        if match:
            print("Failed line: %d:" % (section_offsets[focus_section][0] + match.lineno))
            print(match.line)
        print(error)


if __name__ == "__main__":
    import sys

    sys.exit(main(sys.argv))
